redvox.tests.api1000.common.test_decorators API documentation

# Module `redvox.tests.api1000.common.test_decorators`

Expand source code

    from enum import Enum
    import unittest

    from google.protobuf.internal.enum_type_wrapper import EnumTypeWrapper

    from redvox.api1000.common.decorators import wrap_enum
    from redvox.api1000.proto.redvox_api_m_pb2 import RedvoxPacketM

    class TestDecorators(unittest.TestCase):
        def test_wrap_enum(self):
            @wrap_enum(RedvoxPacketM.StationInformation.OsType)
            class OsType(Enum):
                UNKNOWN_OS: int = 0
                ANDROID: int = 1
                IOS: int = 2
                OSX: int = 3
                LINUX: int = 4
                WINDOWS: int = 5

            os_type = OsType.ANDROID
            self.assertIsNotNone(getattr(os_type, "into_proto", None))
            self.assertIsNotNone(getattr(OsType, "from_proto", None))

            proto_enum: EnumTypeWrapper = os_type.into_proto()
            self.assertEqual(proto_enum, RedvoxPacketM.StationInformation.OsType.ANDROID)
            original_enum: OsType = OsType.from_proto(proto_enum)
            self.assertEqual(original_enum, OsType.ANDROID)

## Classes

`class RedvoxPacketM (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var BYTE`
  `var CENTIMETERS`
  `var DECIBEL`
  `var DECIMAL_DEGREES`
  `var DEGREES_CELSIUS`
  `var DESCRIPTOR`
  `var DoubleSamplePayload`

    A ProtocolMessage

  `var EventStream`

    A ProtocolMessage

  `var KILOPASCAL`
  `var LSB_PLUS_MINUS_COUNTS`
  `var LUX`
  `var METERS`
  `var METERS_PER_SECOND`
  `var METERS_PER_SECOND_SQUARED`
  `var MICROAMPERES`
  `var MICROSECONDS_SINCE_UNIX_EPOCH`
  `var MICROTESLA`
  `var MetadataEntry`

    A ProtocolMessage

  `var NORMALIZED_COUNTS`
  `var PCM`
  `var PERCENTAGE`
  `var RADIANS`
  `var RADIANS_PER_SECOND`
  `var SamplePayload`

    A ProtocolMessage

  `var Sensors`

    A ProtocolMessage

  `var StationInformation`

    A ProtocolMessage

  `var SummaryStatistics`

    A ProtocolMessage

  `var TimingInformation`

    A ProtocolMessage

  `var TimingPayload`

    A ProtocolMessage

  `var UNITLESS`
  `var UNKNOWN`
  `var Unit`

  ### Instance variables

  `var api`

    Field redvox_api_m.RedvoxPacketM.api

  `var event_streams`

    Field redvox_api_m.RedvoxPacketM.event_streams

  `var metadata`

    Field redvox_api_m.RedvoxPacketM.metadata

  `var sensors`

    Field redvox_api_m.RedvoxPacketM.sensors

  `var station_information`

    Field redvox_api_m.RedvoxPacketM.station_information

  `var sub_api`

    Field redvox_api_m.RedvoxPacketM.sub_api

  `var timing_information`

    Field redvox_api_m.RedvoxPacketM.timing_information

`class TestDecorators (methodName='runTest')`

  A class whose instances are single test cases.

  By default, the test code itself should be placed in a method named 'runTest'.

  If the fixture may be used for many test cases, create as many test methods as are needed. When instantiating such a TestCase subclass, specify in the constructor arguments the name of the test method that the instance is to execute.

  Test authors should subclass TestCase for their own tests. Construction and deconstruction of the test's environment ('fixture') can be implemented by overriding the 'setUp' and 'tearDown' methods respectively.

  If it is necessary to override the init method, the base class init method must always be called. It is important that subclasses should not change the signature of their init method, since instances of the classes are instantiated automatically by parts of the framework in order to be run.

  When subclassing TestCase, you can set these attributes: * failureException: determines which exception will be raised when the instance's assertion methods fail; test methods raising this exception will be deemed to have 'failed' rather than 'errored'. * longMessage: determines whether long messages (including repr of objects used in assert methods) will be printed on failure in addition to any explicit message passed. * maxDiff: sets the maximum length of a diff in failure messages by assert methods using difflib. It is looked up as an instance attribute so can be configured by individual tests if required.

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  Expand source code

      class TestDecorators(unittest.TestCase):
          def test_wrap_enum(self):
              @wrap_enum(RedvoxPacketM.StationInformation.OsType)
              class OsType(Enum):
                  UNKNOWN_OS: int = 0
                  ANDROID: int = 1
                  IOS: int = 2
                  OSX: int = 3
                  LINUX: int = 4
                  WINDOWS: int = 5

              os_type = OsType.ANDROID
              self.assertIsNotNone(getattr(os_type, "into_proto", None))
              self.assertIsNotNone(getattr(OsType, "from_proto", None))

              proto_enum: EnumTypeWrapper = os_type.into_proto()
              self.assertEqual(proto_enum, RedvoxPacketM.StationInformation.OsType.ANDROID)
              original_enum: OsType = OsType.from_proto(proto_enum)
              self.assertEqual(original_enum, OsType.ANDROID)

  ### Ancestors

  - unittest.case.TestCase

  ### Methods

  `def test_wrap_enum(self)`
    Expand source code

        def test_wrap_enum(self):
            @wrap_enum(RedvoxPacketM.StationInformation.OsType)
            class OsType(Enum):
                UNKNOWN_OS: int = 0
                ANDROID: int = 1
                IOS: int = 2
                OSX: int = 3
                LINUX: int = 4
                WINDOWS: int = 5

            os_type = OsType.ANDROID
            self.assertIsNotNone(getattr(os_type, "into_proto", None))
            self.assertIsNotNone(getattr(OsType, "from_proto", None))

            proto_enum: EnumTypeWrapper = os_type.into_proto()
            self.assertEqual(proto_enum, RedvoxPacketM.StationInformation.OsType.ANDROID)
            original_enum: OsType = OsType.from_proto(proto_enum)
            self.assertEqual(original_enum, OsType.ANDROID)